@@ -556,7 +556,7 @@ class FSSE(BaseEstimator, ClassifierMixin):
         Sample Code
         -----------
         biggest_fsse_fs, fs_importance = fsse.get_important_features()
-        xfsse = X_scaled[:,biggest_fsse_fs] # 前N个系数 non-zero
+        xfsse = X_scaled[:,biggest_fsse_fs] # 前N个non-zero系数
         plot_feature_importance(np.abs(fs_importance), 'FSSE FS Result') # require feature_importance.py
 
         return
@@ -572,7 +572,7 @@ class FSSE(BaseEstimator, ClassifierMixin):
         biggest_fsse_fs = []
 
         for idx in biggest_fsse_gs:
-            biggest_fsse_fs = biggest_fsse_fs + list(range(idx*SPLIT, (idx+1)*self.feature_split))
+            biggest_fsse_fs = biggest_fsse_fs + list(range(idx* self.feature_split, (idx+1)*self.feature_split))
     
         biggest_fsse_fs = np.array(biggest_fsse_fs)
 
